# SORACOM Orbit Development Environment

This repository contains pre-configured [Visual Studio Code](https://code.visualstudio.com/) development environment for SORACOM Orbit.

- [AssemblyScript](assemblyscript)
- [Rust](rust)
- [C/C++](c)
- [TinyGo](tinygo)

## Prerequisites

- [Docker](https://www.docker.com/)
- [Visual Studio Code](https://code.visualstudio.com/)

## Setup Development Environment

1. Login on [GitHub](https://github.com/) and [fork](https://help.github.com/articles/fork-a-repo/) this repository.
2. Clone your forked repository and update submodules
   ```console
   $ git clone https://github.com/<your-account>/orbit-development-environment.git`
   $ git submodule update --init --recursive
   ```
3. Change the directory to `orbit-development-environment` and open your preferred language with VS Code

   ```console
   $ code assemblyscript # or
   $ code rust # or
   $ code c # or
   $ code tinygo # or
   $ cp launch.example launch # small shell script to create dedicated vscode configurations directory
   $ vi launch # update environment variables
   $ ./launch assemblyscript
   ```
4. If you don't have [Remote - Containers](https://marketplace.visualstudio.com/items?itemName=ms-vscode-remote.remote-containers) extension installed, you will be prompted to install the extension. Click `Install All`.
   - If you disabled the extension recommendation (`"extensions.ignoreRecommendations": true` in your setting), install the extension manually.
5. After successful installation, you will be prompted to reopen workspace in a container. Click `Reopen in Container`.
6. Wait for a while for building development container image.
7. See `README.md` for each programming language environment.

## Tips

Edit `TZ` environment variable to set timezone of the container. Default is set as `Asia/Tokyo`.

You can mount `.ssh`, `.soracom`, or whatever to the development container by editing `.devcontainer/devcontainer.json`. See vscode documentation [Advanced Container Configuration](https://code.visualstudio.com/docs/remote/containers-advanced#_adding-another-local-file-mount) for detail.

```json
{
  "name": "SORACOM Orbit Development Container",
  ...
  "mounts": [
    "source=${localEnv:HOME}${localEnv:USERPROFILE}/.ssh,target=/root/.ssh,type=bind,consistency=cached",
    "source=${localEnv:HOME}${localEnv:USERPROFILE}/.soracom,target=/root/.soracom,type=bind,consistency=cached"
  ]
}
```

If you choose Rust, mounting `~/.cargo` will speed up `cargo build`.

```json
{
  "name": "SORACOM Orbit Development Container",
  ...
  "mounts": [
    "source=${localEnv:HOME}${localEnv:USERPROFILE}/.cargo/git,target=/workspaces/.cargo/git,type=bind,consistency=cached",
    "source=${localEnv:HOME}${localEnv:USERPROFILE}/.cargo/registry,target=/workspaces/.cargo/registry,type=bind,consistency=cached"
  ]
}
```
